@@ -36,6 +36,7 @@ char *get_prog_dir(void);
 #define DIR_DELIM '\\'
 extern const double pi;
 #define myWaitAndProcessNextEvent Nlm_ProcessAnEvent
+#define tempnam _tempnam
 
 #include <conio.h> //temporaire passage CW8
 int __getche(void)
@@ -203,6 +204,11 @@ void remove_arg(int target, int *argc, char *argv[]);
 #ifdef WIN_MAC
 extern int MG_GetInputFName(char *fname, int maxl);
 extern int MG_GetOutputFName(char *fname, int maxl, char *dfault);
+extern QDPictRef MyPictToQDPict(PicHandle mypicture);
+extern int MyQDPictToPDFfile (QDPictRef picture, char *fname);
+#elif defined(WIN_MSWIN)
+extern int MG_GetInputFName(char *fname, int maxl);
+extern int MG_GetOutputFName(char *fname, int maxl, char *dfault);
 #else 
 #define MG_GetOutputFName Nlm_GetOutputFileName
 #define MG_GetInputFName(a,b) Nlm_GetInputFileName(a, b, NULL, NULL)
@@ -797,64 +803,26 @@ return name;
 #ifdef WIN_MAC
 int crefpict(char *fname, PicHandle picture)
 {
-OSErr success = 0, err;
-static char zeros[512];
-Boolean async = false;
-static char strfname[255];
-OSType f_type,f_creator;
-static HParamBlockRec paramblock;
-PicPtr picptr;
-int size;
+QDPictRef myqdpict;
+int err;
 
-
-strcpy(strfname+1, fname);
-*strfname = strlen(fname);
-paramblock.fileParam.ioNamePtr = (StringPtr)&strfname;
-
-
-plotfile = fopen(fname, "wb");
-if( (plotfile == NULL) || (fwrite(zeros,1,512,plotfile) != 512) )
-        return TRUE;
-size = GetHandleSize((Handle)picture);
-HLock( (Handle) picture);
-picptr = *picture;
-if( fwrite(picptr,1,size,plotfile) != size ) return TRUE;
-HUnlock( (Handle) picture);
-fclose(plotfile);
+myqdpict = MyPictToQDPict(picture);
+if(myqdpict != NULL) err = MyQDPictToPDFfile(myqdpict, fname);
+else err = TRUE;
 KillPicture(picture);
-
-
-err = PBHGetFInfoAsync(&paramblock);
-if( err != success ) return FALSE;
-strncpy((char *)&f_type, "PICT", 4);
-strncpy((char *)&f_creator, "ttxt", 4); /* creator = SimpleText */
-paramblock.fileParam.ioFlFndrInfo.fdType = f_type;
-paramblock.fileParam.ioFlFndrInfo.fdCreator = f_creator;
-err = PBHSetFInfoAsync(&paramblock);
-
-
-return FALSE;
+return err;
 }
 
 
-
 void copy_callback(Nlm_IteM unused)
 {
-unsigned long pictlen;
-double currx, curry;
-ScrapRef myscrapref;
+extern void MyCopyPictToClipboard (PicHandle mypicture);
 
 if(notu == 0) return;
 doing_copy = TRUE;
 save_plot_callback(NULL);
 
-ClearCurrentScrap();
-HLock( (Handle) mypicture);
-pictlen = GetHandleSize( (Handle)  mypicture);
-GetCurrentScrap(&myscrapref);
-PutScrapFlavor(myscrapref, 'PICT', 0, pictlen, (Ptr)*mypicture );
-// PutScrap(pictlen, 'PICT', (Ptr)*mypicture);
-HUnlock( (Handle) mypicture);
+MyCopyPictToClipboard (mypicture );
 KillPicture(mypicture);
 doing_copy = FALSE;
 }
@@ -901,7 +869,7 @@ if( ! Nlm_ClipboardHasString() ) {
 	return;
 	}
 buff = Nlm_ClipboardToString();
-tmpfname = tmpnam(NULL);
+tmpfname = tempnam(NULL, "unrootedtemp_");
 tmp = fopen(tmpfname,"w");
 fwrite(buff, 1, strlen(buff), tmp);
 fclose(tmp);
@@ -944,7 +912,7 @@ if(!doing_copy) {
         sp = strchr(plotfilename,'.'); 
         if(sp == NULL) sp = plotfilename + strlen(plotfilename);
 #ifdef WIN_MAC
-        strcpy(sp,".pict");
+        strcpy(sp,".pdf");
 #else
         strcpy(sp,".ps");
 #endif
@@ -1019,7 +987,7 @@ plot_aux_data.ps_plot = FALSE;
         ClosePicture();
         if( !doing_copy ) 
                 if( crefpict(plotfilename, mypicture) ) {
-                        sprintf(message, "Problem writing PICT file %s", plotfilename);
+                        sprintf(message, "Problem writing PDF file %s", plotfilename);
                         err_message(message);
                         }
 #else
